.. toctree::
   :titlesonly:
   :maxdepth: 3
   :hidden:

   userguide/index
   api/index
   devel/index
   examples/index
   userguide/SUPPORT

=====
MetPy
=====

MetPy is a collection of tools in Python for reading, visualizing, and performing calculations
with weather data. MetPy supports Python >= 3.7 and is freely available under a permissive
`open source license <https://github.com/Unidata/MetPy/blob/main/LICENSE>`_.

If you're new to MetPy, check out our :doc:`Getting Started <userguide/startingguide>` guide.

.. raw:: html

    <div class="container">
        <div class="row">
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <span><i class="fas fa-book-open fa-10x"></i></span>
                <div class="card-body d-flex flex-column">
                    <h5 class="card-title">User Guide</h5>
                    <p class="card-text">The user guide provides in-depth information on how
                    to use MetPy, including how to get started. This is where to look for
                    general conceptual descriptions on how to use parts of MetPy, like its
                    support for XArray or units.</p>

.. container:: card-button

    :doc:`To the user guide<userguide/index>`

.. raw:: html

                </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <span><i class="fas fa-list-alt fa-10x"></i></span>
                <div class="card-body d-flex flex-column">
                    <h5 class="card-title">Reference Guide</h5>
                    <p class="card-text">The reference guide contains detailed descriptions on
                    every function and class within MetPy. This is where to turn to understand
                    how to use a particular feature or where to search for a specific tool.</p>

.. container:: card-button

    :doc:`To the reference guide<api/index>`

.. raw:: html

                </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <span><i class="fas fa-laptop-code fa-10x"></i></span>
                <div class="card-body d-flex flex-column">
                    <h5 class="card-title">Developer Guide</h5>
                    <p class="card-text">Want to help make MetPy better? Found something
                    that's not working quite right? You can find instructions on how to
                    contribute to MetPy here. You can also find detailed descriptions on
                    tools useful for developing MetPy.</p>

.. container:: card-button

    :doc:`To the development guide<devel/index>`

.. raw:: html

                </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <span><i class="fas fa-chart-area fa-10x"></i></span>
                <div class="card-body d-flex flex-column">
                    <h5 class="card-title">Examples</h5>
                    <p class="card-text">Check out MetPy's gallery of examples which contains
                    sample code demonstrating various parts of MetPy's functionality.</p>

.. container:: card-button

    :doc:`To the example gallery<examples/index>`

.. raw:: html

                </div>
                </div>
            </div>
        </div>
    </div>

Our up-to-date references for grants and funding can be found `here <https://github.com/Unidata/MetPy/blob/main/CITATION.cff>`_.

.. image:: _static/NSF.jpg
   :width: 100 px
   :align: left
   :alt: National Science Foundation logo

.. image:: _static/unidata_150x150.png
   :width: 100 px
   :align: center
   :alt: Unidata logo
